=== modified file 'loggerhead/controllers/revision_ui.py'
--- loggerhead/controllers/revision_ui.py	2008-12-05 18:52:44 +0000
+++ loggerhead/controllers/revision_ui.py	2009-02-18 01:00:02 +0000
@@ -17,10 +17,15 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
+from StringIO import StringIO
+
+import bzrlib.diff
+
 from paste.httpexceptions import HTTPServerError
 
 from loggerhead import util
 from loggerhead.controllers import TemplatedBranchView
+from loggerhead.history import rich_filename
 
 
 DEFAULT_LINE_COUNT_LIMIT = 3000
@@ -30,6 +35,121 @@
 
     template_path = 'loggerhead.templates.revision'
 
+    def _process_diff(self, diff):
+        # doesn't really need to be a method; could be static.
+        chunks = []
+        chunk = None
+        for line in diff.splitlines():
+            if len(line) == 0:
+                continue
+            if line.startswith('+++ ') or line.startswith('--- '):
+                continue
+            if line.startswith('@@ '):
+                # new chunk
+                if chunk is not None:
+                    chunks.append(chunk)
+                chunk = util.Container()
+                chunk.diff = []
+                split_lines = line.split(' ')[1:3]
+                lines = [int(x.split(',')[0][1:]) for x in split_lines]
+                old_lineno = lines[0]
+                new_lineno = lines[1]
+            elif line.startswith(' '):
+                chunk.diff.append(util.Container(old_lineno=old_lineno,
+                                                 new_lineno=new_lineno,
+                                                 type='context',
+                                                 line=line[1:]))
+                old_lineno += 1
+                new_lineno += 1
+            elif line.startswith('+'):
+                chunk.diff.append(util.Container(old_lineno=None,
+                                                 new_lineno=new_lineno,
+                                                 type='insert', line=line[1:]))
+                new_lineno += 1
+            elif line.startswith('-'):
+                chunk.diff.append(util.Container(old_lineno=old_lineno,
+                                                 new_lineno=None,
+                                                 type='delete', line=line[1:]))
+                old_lineno += 1
+            else:
+                chunk.diff.append(util.Container(old_lineno=None,
+                                                 new_lineno=None,
+                                                 type='unknown',
+                                                 line=repr(line)))
+        if chunk is not None:
+            chunks.append(chunk)
+        return chunks
+
+    def _parse_diffs(self, old_tree, new_tree, delta):
+        """
+        Return a list of processed diffs, in the format::
+
+            list(
+                filename: str,
+                file_id: str,
+                chunks: list(
+                    diff: list(
+                        old_lineno: int,
+                        new_lineno: int,
+                        type: str('context', 'delete', or 'insert'),
+                        line: str,
+                    ),
+                ),
+            )
+        """
+        process = []
+        out = []
+
+        for old_path, new_path, fid, \
+            kind, text_modified, meta_modified in delta.renamed:
+            if text_modified:
+                process.append((old_path, new_path, fid, kind))
+        for path, fid, kind, text_modified, meta_modified in delta.modified:
+            process.append((path, path, fid, kind))
+
+        for old_path, new_path, fid, kind in process:
+            old_lines = old_tree.get_file_lines(fid)
+            new_lines = new_tree.get_file_lines(fid)
+            buffer = StringIO()
+            if old_lines != new_lines:
+                try:
+                    bzrlib.diff.internal_diff(old_path, old_lines,
+                                              new_path, new_lines, buffer)
+                except bzrlib.errors.BinaryFile:
+                    diff = ''
+                else:
+                    diff = buffer.getvalue()
+            else:
+                diff = ''
+            out.append(util.Container(
+                          filename=rich_filename(new_path, kind),
+                          file_id=fid,
+                          chunks=self._process_diff(diff),
+                          raw_diff=diff))
+
+        return out
+
+    def get_change_with_diff(self, revid, compare_revid):
+        h = self._history
+        change = h.get_changes([revid])[0]
+
+        if compare_revid is None:
+            if change.parents:
+                compare_revid = change.parents[0].revid
+            else:
+                compare_revid = 'null:'
+
+        rev_tree1 = h._branch.repository.revision_tree(compare_revid)
+        rev_tree2 = h._branch.repository.revision_tree(revid)
+        delta = rev_tree2.changes_from(rev_tree1)
+
+        change.changes = h.parse_delta(delta)
+        change.changes.modified = self._parse_diffs(rev_tree1,
+                                                    rev_tree2,
+                                                    delta)
+
+        return change
+
     def get_values(self, path, kwargs, headers):
         h = self._history
         revid = self.get_revid()
@@ -57,7 +177,7 @@
             navigation.query = query
         util.fill_in_navigation(navigation)
 
-        change = h.get_change_with_diff(revid, compare_revid)
+        change = self.get_change_with_diff(revid, compare_revid)
         # add parent & merge-point branch-nick info, in case it's useful
         h.get_branch_nicks([change])
 
@@ -67,12 +187,6 @@
             for chunk in file.chunks:
                 line_count += len(chunk.diff)
 
-        # let's make side-by-side diff be the default
-        # FIXME: not currently in use. Should be
-        side_by_side = not kwargs.get('unified', False)
-        if side_by_side:
-            h.add_side_by_side([change])
-
         # Directory Breadcrumbs
         directory_breadcrumbs = (
             util.directory_breadcrumbs(
@@ -92,7 +206,6 @@
             'query': query,
             'remember': remember,
             'compare_revid': compare_revid,
-            'side_by_side': side_by_side,
             'url': self._branch.context_url,
             'line_count': line_count,
             'line_count_limit': line_count_limit,

=== modified file 'loggerhead/history.py'
--- loggerhead/history.py	2009-02-10 04:27:58 +0000
+++ loggerhead/history.py	2009-02-13 02:47:13 +0000
@@ -67,67 +67,6 @@
 
 bzrlib.ui.ui_factory = ThreadSafeUIFactory()
 
-
-def _process_side_by_side_buffers(line_list, delete_list, insert_list):
-    while len(delete_list) < len(insert_list):
-        delete_list.append((None, '', 'context'))
-    while len(insert_list) < len(delete_list):
-        insert_list.append((None, '', 'context'))
-    while len(delete_list) > 0:
-        d = delete_list.pop(0)
-        i = insert_list.pop(0)
-        line_list.append(util.Container(old_lineno=d[0], new_lineno=i[0],
-                                        old_line=d[1], new_line=i[1],
-                                        old_type=d[2], new_type=i[2]))
-
-
-def _make_side_by_side(chunk_list):
-    """
-    turn a normal unified-style diff (post-processed by parse_delta) into a
-    side-by-side diff structure.  the new structure is::
-
-        chunks: list(
-            diff: list(
-                old_lineno: int,
-                new_lineno: int,
-                old_line: str,
-                new_line: str,
-                type: str('context' or 'changed'),
-            )
-        )
-    """
-    out_chunk_list = []
-    for chunk in chunk_list:
-        line_list = []
-        wrap_char = '<wbr/>'
-        delete_list, insert_list = [], []
-        for line in chunk.diff:
-            # Add <wbr/> every X characters so we can wrap properly
-            wrap_line = re.findall(r'.{%d}|.+$' % 78, line.line)
-            wrap_lines = [util.html_clean(_line) for _line in wrap_line]
-            wrapped_line = wrap_char.join(wrap_lines)
-
-            if line.type == 'context':
-                if len(delete_list) or len(insert_list):
-                    _process_side_by_side_buffers(line_list, delete_list,
-                                                  insert_list)
-                    delete_list, insert_list = [], []
-                line_list.append(util.Container(old_lineno=line.old_lineno,
-                                                new_lineno=line.new_lineno,
-                                                old_line=wrapped_line,
-                                                new_line=wrapped_line,
-                                                old_type=line.type,
-                                                new_type=line.type))
-            elif line.type == 'delete':
-                delete_list.append((line.old_lineno, wrapped_line, line.type))
-            elif line.type == 'insert':
-                insert_list.append((line.new_lineno, wrapped_line, line.type))
-        if len(delete_list) or len(insert_list):
-            _process_side_by_side_buffers(line_list, delete_list, insert_list)
-        out_chunk_list.append(util.Container(diff=line_list))
-    return out_chunk_list
-
-
 def is_branch(folder):
     try:
         bzrlib.branch.Branch.open(folder)
@@ -654,26 +593,6 @@
         for entry, changes in zip(entries, changes_list):
             entry.changes = changes
 
-    def get_change_with_diff(self, revid, compare_revid=None):
-        change = self.get_changes([revid])[0]
-
-        if compare_revid is None:
-            if change.parents:
-                compare_revid = change.parents[0].revid
-            else:
-                compare_revid = 'null:'
-
-        rev_tree1 = self._branch.repository.revision_tree(compare_revid)
-        rev_tree2 = self._branch.repository.revision_tree(revid)
-        delta = rev_tree2.changes_from(rev_tree1)
-
-        change.changes = self.parse_delta(delta)
-        change.changes.modified = self._parse_diffs(rev_tree1,
-                                                    rev_tree2,
-                                                    delta)
-
-        return change
-
     def get_file(self, file_id, revid):
         "returns (path, filename, data)"
         inv = self.get_inventory(revid)
@@ -684,100 +603,6 @@
             path = '/' + path
         return path, inv_entry.name, rev_tree.get_file_text(file_id)
 
-    def _parse_diffs(self, old_tree, new_tree, delta):
-        """
-        Return a list of processed diffs, in the format::
-
-            list(
-                filename: str,
-                file_id: str,
-                chunks: list(
-                    diff: list(
-                        old_lineno: int,
-                        new_lineno: int,
-                        type: str('context', 'delete', or 'insert'),
-                        line: str,
-                    ),
-                ),
-            )
-        """
-        process = []
-        out = []
-
-        for old_path, new_path, fid, \
-            kind, text_modified, meta_modified in delta.renamed:
-            if text_modified:
-                process.append((old_path, new_path, fid, kind))
-        for path, fid, kind, text_modified, meta_modified in delta.modified:
-            process.append((path, path, fid, kind))
-
-        for old_path, new_path, fid, kind in process:
-            old_lines = old_tree.get_file_lines(fid)
-            new_lines = new_tree.get_file_lines(fid)
-            buffer = StringIO()
-            if old_lines != new_lines:
-                try:
-                    bzrlib.diff.internal_diff(old_path, old_lines,
-                                              new_path, new_lines, buffer)
-                except bzrlib.errors.BinaryFile:
-                    diff = ''
-                else:
-                    diff = buffer.getvalue()
-            else:
-                diff = ''
-            out.append(util.Container(
-                          filename=rich_filename(new_path, kind),
-                          file_id=fid,
-                          chunks=self._process_diff(diff),
-                          raw_diff=diff))
-
-        return out
-
-    def _process_diff(self, diff):
-        # doesn't really need to be a method; could be static.
-        chunks = []
-        chunk = None
-        for line in diff.splitlines():
-            if len(line) == 0:
-                continue
-            if line.startswith('+++ ') or line.startswith('--- '):
-                continue
-            if line.startswith('@@ '):
-                # new chunk
-                if chunk is not None:
-                    chunks.append(chunk)
-                chunk = util.Container()
-                chunk.diff = []
-                split_lines = line.split(' ')[1:3]
-                lines = [int(x.split(',')[0][1:]) for x in split_lines]
-                old_lineno = lines[0]
-                new_lineno = lines[1]
-            elif line.startswith(' '):
-                chunk.diff.append(util.Container(old_lineno=old_lineno,
-                                                 new_lineno=new_lineno,
-                                                 type='context',
-                                                 line=line[1:]))
-                old_lineno += 1
-                new_lineno += 1
-            elif line.startswith('+'):
-                chunk.diff.append(util.Container(old_lineno=None,
-                                                 new_lineno=new_lineno,
-                                                 type='insert', line=line[1:]))
-                new_lineno += 1
-            elif line.startswith('-'):
-                chunk.diff.append(util.Container(old_lineno=old_lineno,
-                                                 new_lineno=None,
-                                                 type='delete', line=line[1:]))
-                old_lineno += 1
-            else:
-                chunk.diff.append(util.Container(old_lineno=None,
-                                                 new_lineno=None,
-                                                 type='unknown',
-                                                 line=repr(line)))
-        if chunk is not None:
-            chunks.append(chunk)
-        return chunks
-
     def parse_delta(self, delta):
         """
         Return a nested data structure containing the changes in a delta::
@@ -816,13 +641,6 @@
         return util.Container(added=added, renamed=renamed,
                               removed=removed, modified=modified)
 
-    @staticmethod
-    def add_side_by_side(changes):
-        # FIXME: this is a rotten API.
-        for change in changes:
-            for m in change.changes.modified:
-                m.sbs_chunks = _make_side_by_side(m.chunks)
-
     def annotate_file(self, file_id, revid):
         z = time.time()
         lineno = 1

=== modified file 'loggerhead/static/css/diff.css'
--- loggerhead/static/css/diff.css	2009-01-23 19:19:39 +0000
+++ loggerhead/static/css/diff.css	2009-02-18 03:02:28 +0000
@@ -1,137 +1,140 @@
 /*Info Box*/
 .infoContainer {
-	width:970px;
-	padding:10px 10px 0px 10px;
-	margin:0px 0px 10px 0px;
-	color:#666;
-	background:#fcfcfc url(../images/bg_infobox.gif) repeat-y top right;
-	border:1px solid #b7b7b7;
+    width:970px;
+    padding:10px 10px 0px 10px;
+    margin:0px 0px 10px 0px;
+    color:#666;
+    background:#fcfcfc url(../images/bg_infobox.gif) repeat-y top right;
+    border:1px solid #b7b7b7;
 }
 ul#list-files {
-	float:right;
-	width:460px;
-	list-style:none;
-	margin:0px;
-	padding:0px;
-	font:normal 11px/normal sans-serif;
-	color:#000;
+    float:right;
+    width:460px;
+    list-style:none;
+    margin:0px;
+    padding:0px;
+    font:normal 11px/normal sans-serif;
+    color:#000;
 }
 ul#list-files li {
-	width:440px;
-	padding:2px 0px 2px 20px;
-	margin:0px 0px 2px 8px;
-	background:url(../images/ico_file.gif) 2px 0px no-repeat;
+    width:440px;
+    padding:2px 0px 2px 20px;
+    margin:0px 0px 2px 8px;
+    background:url(../images/ico_file.gif) 2px 0px no-repeat;
 }
 ul#list-files li.desc {
     margin-left: 0;
-	background:url(../images/ico_description.gif) 0px 0px no-repeat;
+    background:url(../images/ico_description.gif) 0px 0px no-repeat;
 }
 #infTxt {
-	float:left;
-	width:493px;
-	margin:0px 0px 5px 0px;
+    float:left;
+    width:493px;
+    margin:0px 0px 5px 0px;
 }
 .information, .committer, .timer, .mfrom, .mto, .revid {
-	clear:both;
-	margin:0px;
-	padding:0px 0px 2px 18px;
-	font:normal 11px/1.3 sans-serif;
-	color:#666;
-	background:url(../images/ico_description.gif) no-repeat top left;
+    clear:both;
+    margin:0px;
+    padding:0px 0px 2px 18px;
+    font:normal 11px/1.3 sans-serif;
+    color:#666;
+    background:url(../images/ico_description.gif) no-repeat top left;
 }
 .revid {
     padding:1px 0px 0px 18px;
     margin:0px 10px 5px 0px;
 }
 .committer, .mfrom, .mto {
-	color:#000;
-	padding:1px 0px 0px 18px;
-	margin:0px 10px 5px 0px;
-	float:left;
-	display:inline;
-	background:url(../images/ico_committer.gif) no-repeat 2px 0px;
+    color:#000;
+    padding:1px 0px 0px 18px;
+    margin:0px 10px 5px 0px;
+    float:left;
+    display:inline;
+    background:url(../images/ico_committer.gif) no-repeat 2px 0px;
 }
 .timer {
-	margin:0px 10px 5px 0px;
-	padding:1px 0px 0px 18px;
-	float:left;
-	clear:none;
-	display:inline;
-	background:url(../images/ico_time.gif) no-repeat top left;
+    margin:0px 10px 5px 0px;
+    padding:1px 0px 0px 18px;
+    float:left;
+    clear:none;
+    display:inline;
+    background:url(../images/ico_time.gif) no-repeat top left;
 }
 .mfrom {
-	background:url(../images/ico_mergefrom.gif) no-repeat top left;
+    background:url(../images/ico_mergefrom.gif) no-repeat top left;
 }
 .mto {
-	background:url(../images/ico_mergeto.gif) no-repeat top left;
+    background:url(../images/ico_mergeto.gif) no-repeat top left;
 }
 /**/
 #loggerheadCont p.expand, #loggerheadCont p.expand a, #loggerheadCont p.expand a:link, #loggerheadCont p.expand a:visited, #loggerheadCont p.expand a:hover {
-	color:#0f6b97;
-	text-decoration:none;
-	margin-right:10px;
-	float:left;	
+    color:#0f6b97;
+    text-decoration:none;
+    margin-right:10px;
+    float:left;	
 }
 #loggerheadCont p.codin, #loggerheadCont p.codin a, #loggerheadCont p.codin a:link, #loggerheadCont p.codin a:visited, #loggerheadCont p.codin a:hover {
-	color:#000;
-	font-size:12px;
-	text-decoration:none;
-	margin-right:10px;
-	float:left;	
+    color:#000;
+    font-size:12px;
+    text-decoration:none;
+    margin-right:10px;
+    float:left;	
 }
 /*Diff Boxes*/
 .diffBox {
-	width:100%;
-	padding:6px 0%;
-	background:#eef6fa;
-	border:1px solid #d2d2d2;
-	margin:10px 0px 0px 0px;
+    width:100%;
+    padding:6px 0%;
+    background:#eef6fa;
+    border:1px solid #d2d2d2;
+    margin:10px 0px 0px 0px;
 }
 .diffBox img {
-	vertical-align:middle;
+    vertical-align:middle;
 }
 .diffBox a, .diffBox a:link, .diffBox a:visited, .diffBox a:hover {
-	text-decoration:none;
+    text-decoration:none;
 }
 .diff {
     margin: 2em 0 2em 0;
 }
 .lineNumber {
-	float:left;
-	width:2%;
-	padding:0px 1%; 
-	border-right:1px solid #d5d5d5;
-	border-left:1px solid #d5d5d5;
-	color:#000;
-	background:#f8fbfd;
-	font:normal 12px/1.8 monospace;
-	text-align:right;
-}
-.lineCode, .removecode, .addcode {
-	float:left;
-	width:43%;
-	padding:0px 1%; 
-	color:#000;
-	background:#fff;
-	font:normal 12px/1.8 monospace;
-}
-.delete, .insert {
-	display:block;
-	background:#ff7f7f;
-}
-.insert {
-	background:#92ed92;
+    width:2%;
+    border-right:1px solid #d5d5d5;
+    border-left:1px solid #d5d5d5;
+    background:#f8fbfd;
+    text-align:right;
+}
+.unified .lineNumber.second {
+    border-left:0px;
+}
+.code, .lineNumber {
+    float:left;
+    padding:0px 1%;
+    color:#000;
+    font:normal 12px/1.8 monospace;
+}
+.blank {
+    float: left;
+    padding:0px 1%;
+    background:#f8fbfd;
+}
+.unified .code { width:89%; }
+.sbs .code, .blank { width:43%; }
+.code.insert {
+    background:#92ed92;
+}
+.code.delete {
+    background:#ff7f7f;
 }
 .separate {
     height: 2em;
     background: #e3e3e3;
 }
 ul#pages {
-	margin-top:10px;
+    margin-top:10px;
 }
 /*Foot Links*/
 #loggerheadCont p.lpandbzr {
-	float:left;
-	padding:3px 0px 0px 0px;
-	margin-top:10px;
+    float:left;
+    padding:3px 0px 0px 0px;
+    margin-top:10px;
 }

=== modified file 'loggerhead/static/css/global.css'
--- loggerhead/static/css/global.css	2009-01-23 20:53:40 +0000
+++ loggerhead/static/css/global.css	2009-02-18 03:32:01 +0000
@@ -337,3 +337,6 @@
 	background:#fcfcfc;
 	border:1px solid #b7b7b7;
 }
+.show_if_js {
+    display: none;
+}
\ No newline at end of file

=== added file 'loggerhead/static/javascript/diff.js'
--- loggerhead/static/javascript/diff.js	1970-01-01 00:00:00 +0000
+++ loggerhead/static/javascript/diff.js	2009-02-18 03:32:01 +0000
@@ -0,0 +1,111 @@
+YUI().use(
+  "node", function (Y) {
+    var unified = true;
+
+    function make_unified(chunk) {
+      var pending_added = [];
+      function flush_adds(before) {
+        for (var i = 0; i < pending_added.length; i++) {
+          before.ancestor().insertBefore(pending_added[i], before);
+        }
+        pending_added.length = 0;
+      }
+      chunk.get('children').filter(".pseudorow").each(
+        function (line) {
+          if (line.hasClass("context")) {
+            flush_adds(line);
+            line.removeChild(line.query('.code'));
+          }
+          else if (line.hasClass("both")) {
+            var added_line = line.create('<div class="pseudorow insert"><div class="lineNumber first">&nbsp;</div><div class="clear">&nbsp;</div></div>');
+            var clear = added_line.query('.clear');
+            added_line.insertBefore(line.query('.lineNumber.second'), clear);
+            added_line.insertBefore(line.query('.code.insert'), clear);
+            pending_added[pending_added.length] = added_line;
+            line.insertBefore(line.create('<div class="lineNumber second">&nbsp;</div>'), line.query('.code.delete'));
+            line.replaceClass("both", "delete");
+          }
+          else if (line.hasClass("insert")) {
+            flush_adds(line);
+            line.removeChild(line.query('.blank'));
+          }
+          else if (line.hasClass("delete")) {
+            line.removeChild(line.query('.blank'));
+            line.insertBefore(line.query('.lineNumber.second'), line.query('.code.delete'));
+          }
+        });
+      flush_adds(null);
+      chunk.replaceClass('sbs', 'unified');
+    }
+
+    function make_sbs(chunk) {
+      var added = [];
+      var removed = [];
+      function clear_bufs(before) {
+        if (!added.length && !removed.length) return;
+        Y.log('hai');
+        var common = Math.min(added.length, removed.length);
+        for (var i = 0; i < common; i++) {
+          var a = added[i];
+          var r = removed[i];
+          a.ancestor().removeChild(a);
+          r.removeChild(r.query('.lineNumber.second'));
+          r.insertBefore(a.query('.lineNumber.second'), r.query('.clear'));
+          r.insertBefore(a.query('.code.insert'), r.query('.clear'));
+          r.replaceClass('removed', 'both');
+        }
+        Y.log('hai');
+        if (added.length > removed.length) {
+          for (var j = common; j < added.length; j++) {
+            a = added[j];
+            a.insertBefore(a.create('<div class="blank">&nbsp;</div>'), a.query('.lineNumber.second'));
+          }
+        }
+        else if (added.length < removed.length) {
+          for (var j = common; j < removed.length; j++) {
+            r = removed[j];
+            r.insertBefore(r.query('.code.delete'), r.query('.lineNumber.second'));
+            r.insertBefore(r.create('<div class="blank">&nbsp;</div>'), r.query('.clear'));
+          }
+        }
+        added.length = 0;
+        removed.length = 0;
+      }
+      chunk.get('children').filter(".pseudorow").each(
+        function (line) {
+          if (line.hasClass("context")) {
+            clear_bufs(line);
+            line.insertBefore(line.query('.code').cloneNode(true), line.query(".second"));
+          }
+          else if (line.hasClass("insert")) {
+            added[added.length] = line;
+          }
+          else if (line.hasClass("delete")) {
+            removed[removed.length] = line;
+          }
+        });
+      clear_bufs(null);
+      chunk.replaceClass('unified', 'sbs');
+
+    }
+
+    function toggle_unified_sbs(event) {
+      event.preventDefault();
+      if (unified) {
+        Y.all(".pseudotable").each(make_sbs);
+        unified = false;
+        Y.get("#toggle_unified_sbs").set('textContent', "Show unified diffs");
+      }
+      else {
+        Y.all(".pseudotable").each(make_unified);
+        unified = true;
+        Y.get("#toggle_unified_sbs").set('textContent', "Show diffs side-by-side");
+      }
+    }
+
+    Y.on("click", toggle_unified_sbs, '#toggle_unified_sbs');
+    Y.on(
+      "domready", function () {
+        Y.all(".show_if_js").removeClass("show_if_js");
+      });
+  });
\ No newline at end of file

=== modified file 'loggerhead/templates/macros.pt'
--- loggerhead/templates/macros.pt	2008-10-25 18:41:18 +0000
+++ loggerhead/templates/macros.pt	2009-02-18 01:39:26 +0000
@@ -19,6 +19,9 @@
       <script type="text/javascript"
               tal:attributes="src
               python:branch.static_url('/static/javascript/yui/build/yui/yui-min.js')"></script>
+      <script type="text/javascript"
+              tal:attributes="src
+              python:branch.static_url('/static/javascript/yui/build/node/node-min.js')"></script>
     <metal:block metal:define-slot="header_extras" />
   </head>
 

=== modified file 'loggerhead/templates/revision.pt'
--- loggerhead/templates/revision.pt	2009-01-23 20:53:40 +0000
+++ loggerhead/templates/revision.pt	2009-02-18 03:43:43 +0000
@@ -9,6 +9,8 @@
       <metal:block fill-slot="header_extras">
         <link rel="stylesheet" type="text/css" media="all"
               tal:attributes="href python:branch.static_url('/static/css/diff.css')"/>
+        <script type="text/javascript"
+                tal:attributes="src python:branch.static_url('/static/javascript/diff.js')"></script>
       </metal:block>
     </head>
 
@@ -26,60 +28,61 @@
             <span metal:use-macro="breadcrumbs/directory"></span>
           </tal:no-link>
           <span>: <tal:revno content="change/revno"></tal:revno>
-        <tal:compare-to condition="python:compare_revid is not None">
-          (compared to revision <tal:block content="python:history.get_revno(compare_revid)" />)
-          </tal:compare-to>
+            <tal:compare-to condition="python:compare_revid is not None">
+              (compared to revision <tal:block content="python:history.get_revno(compare_revid)" />)
+            </tal:compare-to>
         </span></h1>
         <tal:branch-info replace="structure python:branchinfo(branch)" />
         <ul id="submenuTabs">
-            <li id="first"><a tal:attributes="href python:url(['/files', change.revno]); 
-                                               title string:browse files at revision ${change/revno}"
-                               tal:content="string:browse files at revision ${change/revno}"></a></li>
-            <li tal:condition="python:remember != change.revno">
-                <a tal:attributes="href python:url(['/revision', change.revno], remember=change.revno, compare_revid=None); 
-                                   title string:compare with another revision"
-                   tal:content="string:Compare with another revision"></a></li>       
-            <li tal:condition="python:(remember is not None) and (compare_revid is None) and (change.revno != remember)" >
-                <a tal:attributes="href python:url(['/revision', change.revno], compare_revid=history.get_revno(remember))">
-                compare with revision <tal:b content="python:history.get_revno(remember)" />
-                </a>
-            </li>
-            <li>
+          <li id="first"><a tal:attributes="href python:url(['/files', change.revno]);
+                                            title string:browse files at revision ${change/revno}"
+                            tal:content="string:browse files at revision ${change/revno}"></a></li>
+          <li tal:condition="python:remember != change.revno">
+            <a tal:attributes="href python:url(['/revision', change.revno], remember=change.revno, compare_revid=None);
+                               title string:compare with another revision"
+               tal:content="string:Compare with another revision"></a></li>
+          <li tal:condition="python:(remember is not None) and (compare_revid is None) and (change.revno != remember)" >
+            <a tal:attributes="href python:url(['/revision', change.revno], compare_revid=history.get_revno(remember))">
+              compare with revision <tal:b content="python:history.get_revno(remember)" />
+            </a>
+          </li>
+          <li>
             <a tal:condition="python:len(change.parents) > 0 and compare_revid is None"
-                   tal:attributes="href python:url(['/diff', change.revno], clear=1)">download diff</a>
+               tal:attributes="href python:url(['/diff', change.revno], clear=1)">download diff</a>
             <a tal:condition="python:compare_revid is not None"
-                   tal:attributes="href python:url(['/diff', change.revno, history.get_revno(compare_revid)], clear=1)">download diff</a>
-            </li>
-            <li id="last"><a tal:attributes="href python:url(['/changes', change.revno]); 
-                                  title string:view history from revision ${change/revno}"
-                  tal:content="string:view history from revision ${change/revno}"></a></li>
+               tal:attributes="href python:url(['/diff', change.revno, history.get_revno(compare_revid)], clear=1)">download diff</a>
+          </li>
+          <li id="last"><a tal:attributes="href python:url(['/changes', change.revno]);
+                                           title string:view history from revision ${change/revno}"
+                           tal:content="string:view history from revision ${change/revno}"></a></li>
         </ul>
 
         <tal:we-are-comparing condition="python:compare_revid is not None">
-        <ul id="submenuTabs">
-          <li id="first">
+          <ul id="submenuTabs">
+            <li id="first">
               <a tal:attributes="href python:url([ '/revision', history.get_revno(compare_revid) ], remember=change.revno, compare_revid=change.revno)">
                 reverse the comparison (<tal:b content="change/revno" /> to <tal:b content="python:history.get_revno(compare_revid)" />)
               </a>
-          </li>
-          <li id="last">
+            </li>
+            <li id="last">
               <a tal:attributes="href python:url(['/revision', change.revno], remember=None, compare_revid=None)">
                 stop comparing with revision <tal:b content="python:history.get_revno(compare_revid)" />
               </a>
-          </li>
-        </ul>
+            </li>
+          </ul>
         </tal:we-are-comparing>
-        
+
         <tal:revision-info replace="structure python:revisioninfo(url, branch, change, modified_file_link_rev)" />
         <p class="expand" id="expand_all" style="display:none;"><a tal:attributes="href string:javascript:toggle_expand_all_revisionview('open')">
             <img tal:attributes="src python:branch.static_url('/static/images/treeCollapsed.png')"
-                  alt="expand all" /> expand all</a>
+                 alt="expand all" /> expand all</a>
         </p>
         <p class="expand" id="collapse_all"><a tal:attributes="href string:javascript:toggle_expand_all_revisionview('close')">
             <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png')"
-                  alt="collapse all" /> collapse all</a>
+                 alt="collapse all" /> collapse all</a>
         </p>
-        <!-- Table -->        
+        <!-- Table -->
+        <p class="expand show_if_js"><a id="toggle_unified_sbs" href="#">Show diffs side-by-side</a></p>
         <p class="codin"><img tal:attributes="src python:branch.static_url('/static/images/newCode.gif')" alt="added" /> added</p>
         <p class="codin"><img tal:attributes="src python:branch.static_url('/static/images/deleteCode.gif')" alt="removed" /> removed</p>
         <div class="clear"><!-- --></div>
@@ -88,87 +91,64 @@
 
       <div metal:fill-slot="content">
         <div class="diff"
-             tal:condition="change/changes/modified"
-             tal:define="uniqs python:{}">
-          <!-- ! side-by-side diff -->
-          <tal:block repeat="item change/changes/modified">
-
-              <tal:u define="u python:util.uniq(uniqs, item.file_id)">
-                      <div class="diffBox"><img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png');
-                                                                title python:branch.static_url('/static/images/treeCollapsed.png');
-                                                                alt python:branch.static_url('/static/images/treeExpanded.png')"
-                                                                class="expand_diff" />
-                                           <a tal:attributes="href python:url(['/annotate', change.revno], clear=1, file_id=item.file_id);
-                                                              id string:${item/filename}-s;
-                                                              title string:Annotate ${item/filename}"
-                                              tal:content="item/filename"></a></div>
-               <div id="psuedotable" class="diffinfo">
-               <tal:block repeat="chunk item/sbs_chunks">
-
-                <tal:block condition="not:repeat/chunk/start">
-                 <div class="lineNumber separate"></div>
-                 <div class="lineCode separate"></div>
-                 <div class="lineNumber separate"></div>
-                 <div class="lineCode separate"></div>
-                 <div class="clear"><!-- --></div>
-                </tal:block>
-
-                <tal:block repeat="line chunk/diff">
-                    <div id="pseudorow">
-                    <tal:block condition="line/old_lineno">
-                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.old_lineno)" /></div>
-                        <div tal:attributes="class string:lineCode ${line/old_type}">
-                            <tal:block replace="structure python:util.fill_div(line.old_line)" />
-                        </div>
-                    </tal:block>
-
-                    <tal:block condition="not:line/old_lineno">
-                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.old_lineno)" /></div>
-                        <div tal:attributes="class string:lineCode ${line/old_type}">
-                            <tal:block replace="structure python:util.fill_div(line.old_line)" />
-                        </div>
-                    </tal:block>
-
-                    <tal:block condition="line/new_lineno">
-                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.new_lineno)" /></div>
-                        <div tal:attributes="class string:lineCode ${line/new_type}">
-                            <tal:block replace="structure python:util.fill_div(line.new_line)" />
-                        </div>
-                    </tal:block>
-
-                    <tal:block condition="not:line/new_lineno">
-                    <div class="lineNumber"><tal:block replace="structure python:util.fill_div(line.new_lineno)" /></div>
-                        <div tal:attributes="class string:lineCode ${line/new_type}">
-                            <tal:block replace="structure python:util.fill_div(line.new_line)" />
-                        </div>
-                    </tal:block>
-                    <div class="clear"><!-- --></div>
-                    </div>
-                   </tal:block>
-                 </tal:block>
-                 </div>
-              </tal:u>
-            </tal:block>
+             tal:repeat="item change/changes/modified">
+
+          <div class="diffBox">
+            <img tal:attributes="src python:branch.static_url('/static/images/treeExpanded.png');
+                                 title python:branch.static_url('/static/images/treeCollapsed.png');
+                                 alt python:branch.static_url('/static/images/treeExpanded.png')"
+                 class="expand_diff" />
+            <a tal:attributes="href python:url(['/annotate', change.revno], clear=1, file_id=item.file_id);
+                               id string:${item/filename}-s;
+                               title string:Annotate ${item/filename}"
+               tal:content="item/filename">
+            </a>
+          </div>
+          <div class="diffinfo">
+            <div class="pseudotable unified"
+                 tal:repeat="chunk item/chunks">
+
+              <tal:block condition="not:repeat/chunk/start">
+                <div class="pseudorow context">
+                  <div class="lineNumber separate"></div>
+                  <div class="lineNumber second separate"></div>
+                  <div class="code separate"></div>
+                  <div class="clear"><!-- --></div>
+                </div>
+              </tal:block>
+
+              <div tal:repeat="line chunk/diff"
+                   tal:attributes="class string:pseudorow ${line/type}">
+                <div class="lineNumber"
+                     tal:content="structure python:util.fill_div(line.old_lineno)"></div>
+                <div class="lineNumber second"
+                     tal:content="structure python:util.fill_div(line.new_lineno)"></div>
+                <div tal:attributes="class string:code ${line/type}"
+                     tal:content="structure python:util.fill_div(util.html_clean(line.line))"></div>
+                <div class="clear"><!-- --></div>
+              </div>
+            </div>
+          </div>
         </div>
 
         <ul tal:condition="python:navigation.prev_page_revid or navigation.next_page_revid"
             id="pages">
-            <li tal:condition="navigation/prev_page_revid" 
-                class="previous">
-                <a tal:attributes="href navigation/prev_page_url">&laquo; Previous</a>
-            </li>
-            <!-- FIXME: Leaving this to eventually show page numbers. Can't show all of them,
-                        so some magic has to be done to just show the previous and next N page numbers
+          <li tal:condition="navigation/prev_page_revid"
+              class="previous">
+            <a tal:attributes="href navigation/prev_page_url">&laquo; Previous</a>
+          </li>
+          <!-- FIXME: Leaving this to eventually show page numbers. Can't show all of them,
+               so some magic has to be done to just show the previous and next N page numbers
 
-            <li class="active">1</li>
-            <tal:block tal:repeat="page_number python:range(navigation.page_count)">
-            <li><a href="#"
-                   tal:content="page_number"></a></li>
+               <li class="active">1</li>
+               <tal:block tal:repeat="page_number python:range(navigation.page_count)">
+                 <li><a href="#"
+                        tal:content="page_number"></a></li>
                </tal:block>-->
-            <li tal:condition="navigation/next_page_revid"
-                class="next">
-                <a tal:attributes="href navigation/next_page_url">Next &raquo;</a>
-            </li>
+          <li tal:condition="navigation/next_page_revid"
+              class="next">
+            <a tal:attributes="href navigation/next_page_url">Next &raquo;</a>
+          </li>
         </ul>
 
       </div>

=== modified file 'loggerhead/tests/test_controllers.py'
--- loggerhead/tests/test_controllers.py	2009-02-13 02:07:29 +0000
+++ loggerhead/tests/test_controllers.py	2009-02-17 00:56:57 +0000
@@ -28,10 +28,11 @@
 
     def make_bzrbranch_and_revision_ui_for_tree_shapes(self, shape1, shape2):
         tree = self.make_branch_and_tree('.')
-        self.build_tree(shape1)
+        self.build_tree_contents(shape1)
+        tree.smart_add([])
         tree.commit('')
         tree.smart_add([])
-        self.build_tree(shape2)
+        self.build_tree_contents(shape2)
         tree.commit('')
         tree.branch.lock_read()
         self.addCleanup(tree.branch.unlock)

